@@ -1,6 +1,8 @@
 from six import PY3
 from six import string_types
 
+assert PY3  ## Still using python2?  Write an issue on the github issue tracker, and I will consider to offer some limited python2-support for the 1.x-series of caldav - otherwise I will start cleaning away code for supporting python2 in the 1.1-release
+
 
 def isPython3():
     """Deprecated. Use six.PY3"""
@@ -8,23 +10,27 @@ def isPython3():
 
 
 def to_wire(text):
-    if text is not None and isinstance(text, string_types) and PY3:
+    if text is None:
+        return None
+    if isinstance(text, string_types) and PY3:
         text = bytes(text, "utf-8")
     elif not PY3:
         text = to_unicode(text).encode("utf-8")
+    text = text.replace(b"\n", b"\r\n")
+    text = text.replace(b"\r\r\n", b"\r\n")
     return text
 
 
 def to_local(text):
-    if text is not None and not isinstance(text, string_types):
+    if text is None:
+        return None
+    if not isinstance(text, string_types):
         text = text.decode("utf-8")
+    text = text.replace("\r\n", "\n")
     return text
 
 
-def to_str(text):
-    if text and not isinstance(text, string_types):
-        text = text.decode("utf-8")
-    return text
+to_str = to_local
 
 
 def to_normal_str(text):
@@ -33,10 +39,13 @@ def to_normal_str(text):
     Make sure we return a normal string, no matter what version of
     python ...
     """
-    if PY3 and text and not isinstance(text, str):
+    if text is None:
+        return text
+    if PY3 and not isinstance(text, str):
         text = text.decode("utf-8")
-    elif not PY3 and text and not isinstance(text, str):
+    elif not PY3 and not isinstance(text, str):
         text = text.encode("utf-8")
+    text = text.replace("\r\n", "\n")
     return text
 
 
